@@ -20,7 +20,7 @@ from django.views.decorators.csrf import csrf_exempt
 from rest_framework import routers
 from django.urls import path
 from data.views.views import HardwareViewSet, AccessoryViewSet, CalibrationViewSet, ChannelViewSet, HubViewSet, \
-    IOViewSet, signup
+    IOViewSet, signup,listHubAccessories,listHubHardware,listHubChannels
 from django.contrib.auth.views import LoginView
 
 
@@ -76,9 +76,9 @@ urlpatterns = [
     path('hub/', csrf_exempt(HubViewSet.postHub)),
     path('pipico/', csrf_exempt(HardwareViewSet.postHardware)),
 
-    path('hubs/<uuid:hub_id>/hardwares', HubViewSet.listHubHardware),
-    path('hubs/<uuid:hub_id>/channels', HubViewSet.listHubChannels),
-    path('hubs/<uuid:hub_id>/accessories', HubViewSet.listHubAccessories),
+    path('hubs/<uuid:hub_id>/hardwares', listHubHardware),
+    path('hubs/<uuid:hub_id>/channels', listHubChannels),
+    path('hubs/<uuid:hub_id>/accessories', listHubAccessories),
     path('openhubapi/about', HubViewSet.about),
     path('streams/', video_streams, name="video_streams"),
     url(r'^signup/$', signup, name='signup'),
